@@ -19,12 +19,15 @@ import re
 import shutil
 import six
 import tempfile
+import warnings
 import yaml
 
 import jinja2
 
 from tripleo_common import constants
-from tripleo_common import exception
+
+
+warnings.filterwarnings('once')
 
 
 class Config(object):
@@ -95,40 +98,35 @@ class Config(object):
         env.trim_blocks = True
         return env, templates_path
 
+    def get_role_config(self):
+        role_config = self.stack_outputs.get('RoleConfig', {})
+        # RoleConfig can exist as a stack output but have a value of None
+        return role_config or {}
+
     @staticmethod
     def _open_file(path):
         return os.fdopen(os.open(path,
                                  os.O_WRONLY | os.O_CREAT, 0o600),
                          'w')
 
-    def _step_tags_to_when(self, sorted_tasks):
-        for task in sorted_tasks:
-            tag = task.get('tags', '')
-            match = re.search('step([0-9]+)', tag)
-            if match:
-                step = match.group(1)
-                whenexpr = task.get('when', None)
-                if whenexpr is None:
-                    task.update({"when": "step|int == %s" % step})
-                else:
-                    # Handle when: foo and a list of when conditionals
-                    if not isinstance(whenexpr, list):
-                        whenexpr = [whenexpr]
-                    for w in whenexpr:
-                        when_exists = re.search('step|int == [0-9]', "%s" % w)
-                        if when_exists:
-                            break
-                    if when_exists:
-                        # Skip to the next task,
-                        # there is an existing 'step|int == N'
-                        continue
-                    whenexpr.insert(0, "step|int == %s" % step)
-                    task['when'] = whenexpr
-
     def _write_playbook_get_tasks(self, tasks, role, filepath):
         playbook = []
-        sorted_tasks = sorted(tasks, key=lambda x: x.get('tags', None))
-        self._step_tags_to_when(sorted_tasks)
+
+        def get_key(task):
+            whenexpr = task.get('when', None)
+            if whenexpr is None:
+                return ''
+            if not isinstance(whenexpr, list):
+                whenexpr = [whenexpr]
+            for w in whenexpr:
+                # make \|int optional incase forgotten; use only step digit:
+                match = re.search('step(\|int)? == ([0-9]+)', "%s" % w)
+                if match:
+                    matches = len(match.groups())
+                    return match.group(matches)
+            return ''
+
+        sorted_tasks = sorted(tasks, key=get_key)
         playbook.append({'name': '%s playbook' % role,
                          'hosts': role,
                          'tasks': sorted_tasks})
@@ -190,7 +188,7 @@ class Config(object):
                         yaml.safe_dump(data,
                                        conf_file,
                                        default_flow_style=False)
-        role_config = self.stack_outputs.get('RoleConfig', {})
+        role_config = self.get_role_config()
         for config_name, config in six.iteritems(role_config):
             conf_path = os.path.join(tmp_path, config_name + ".yaml")
             with self._open_file(conf_path) as conf_file:
@@ -270,16 +268,35 @@ class Config(object):
             group_var_server_template = env.get_template('group_var_server.j2')
 
             for d in deployments:
-                if isinstance(d['config'], dict):
-                    d['config'] = json.dumps(d['config'])
+
+                # See if the config can be loaded as a JSON data structure
+                # In some cases, it may already be JSON (hiera), or it may just
+                # be a string (script). In those cases, just use the value
+                # as-is.
+                try:
+                    data = json.loads(d['config'])
+                except Exception:
+                    data = d['config']
+
+                # If the value is not a string already, pretty print it as a
+                # string so it's rendered in a readable format.
+                if not isinstance(data, six.text_type):
+                    data = json.dumps(data, indent=2)
+
+                d['config'] = data
+
+                # The hiera Heat hook expects an actual dict for the config
+                # value, not a scalar. All other hooks expect a scalar.
                 if d['group'] == 'hiera':
                     d['scalar'] = False
                 else:
                     d['scalar'] = True
 
                 if d['group'] == 'os-apply-config':
-                    raise exception.GroupOsApplyConfigException(
-                        d['deployment_name'])
+                    message = ("group:os-apply-config is deprecated. "
+                               "Deployment %s will not be applied by "
+                               "config-download." % d['deployment_name'])
+                    warnings.warn(message, DeprecationWarning)
 
             with open(group_var_server_path, 'w') as f:
                 f.write(group_var_server_template.render(
